@@ -1,3 +1,5 @@
+from enum import Enum
+
 from PyQt5 import QtGui, QtCore
 
 
@@ -146,6 +148,20 @@ class FillStyle:
     """Not fill at all. For example, draw_circle() will not fill."""
     SOLID_FILL = QtCore.Qt.SolidPattern
     """Fill with solid color. see set_fill_color()."""
+    LINE_FILL = QtCore.Qt.HorPattern
+    """Fill with horizontal lines."""
+    LTSLASH_FILL = QtCore.Qt.BDiagPattern
+    SLASH_FILL = QtCore.Qt.BDiagPattern
+    """File with diagonal lines."""
+    BKSLASH_FILL = QtCore.Qt.FDiagPattern
+    LTBKSLASH_FILL = QtCore.Qt.FDiagPattern
+    """File with diagonal lines."""
+    HATCH_FILL = QtCore.Qt.CrossPattern
+    XHATCH_FILL = QtCore.Qt.DiagCrossPattern
+ #   INTERLEAVE_FILL
+    WIDE_DOT_FILL = QtCore.Qt.Dense7Pattern
+    CLOSE_DOT_FILL = QtCore.Qt.Dense6Pattern
+
 
 
 class Color:
@@ -200,6 +216,9 @@ class Color:
     """White"""
     TRANSPARENT = QtCore.Qt.transparent
     """Transparent"""
+    Values = (BLACK,BLUE,GREEN,CYAN,RED,MAGENTA,BROWN,LIGHT_GRAY,DARK_GRAY,LIGHT_BLUE,
+              LIGHT_GREEN,LIGHT_CYAN,LIGHT_RED,LIGHT_MAGENTA,YELLOW,WHITE,LIGHT_YELLOW,
+              DARK_BLUE,DARK_CYAN,DARK_GREEN,DARK_MAGENTA,DARK_RED,DARK_YELLOW)
 
 
 class TextFlags:
@@ -232,13 +251,15 @@ class TextFlags:
     """Breaks lines at appropriate points, e.g. at word boundaries."""
 
 
-class MouseMessageType:
+class MouseMessageType(Enum):
     """
     These are the mouse message types.
     """
     NO_MESSAGE = 0
     PRESS_MESSAGE = 1
     RELEASE_MESSAGE = 2
+    DOUBLE_CLICK_MESSAGE = 3
+
 
 
 class FillRule:
