@@ -8,8 +8,5 @@ set_color(Color.RED)
 set_fill_color(Color.LIGHT_BLUE)
 draw_circle(200, 200, 100)
 
-img = get_target()
-image = img.get_image()
-
 pause()
 close_graph()
